Welcome to flowchem
===================

 
![github-actions](https://github.com/cambiegroup/flowchem/actions/workflows/python-app.yml/badge.svg)
![Docs](https://readthedocs.org/projects/flowchem/badge/?version=latest)
[![PyPI version fury.io](https://badge.fury.io/py/flowchem.svg)](https://pypi.org/project/flowchem/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/flowchem.svg)](https://pypi.python.org/pypi/flowchem/)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)
[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)

Flowchem is a python library to control a variety of instruments commonly found in chemistry labs.

Currently, those include:
 - Pumps (Knauer P2.1, Harvard Apparatus Elite 11, Hamilton ML600)
 - Valves (ViciValco and Knauer)
 - Thermostat (Huber)
 - Analytical instruments (Magritek Spinsolve benchtop NMR and Mattler Toledo FlowIR)
 - General purpose sensors-actuators from Phidgets (e.g. 4...20 mA sensor to interface with Swagelok pressure sensors)

## Table of Contents
* [Installation](#installation)
* [Usage](#usage)
* [License](#license)
* [Questions](#questions)

 
## Installation
```bash
pip install flowchem
```


## Usage
{WRITE ME}

## License
This project is released under the terms of the MIT License.

## Questions
For questions about this project, fell free to open a GitHub issue, or reach out by email at dario.cambie@mpikg.mpg.de.
